@@ -1379,6 +1379,28 @@ WITHDRAW = construct.Struct(
 )
 
 
+# /// Cache prices
+# ///
+# /// Accounts expected: 3 + Oracles
+# /// 0. `[]` mango_group_ai -
+# /// 1. `[writable]` mango_cache_ai -
+# /// 2+... `[]` oracle_ais - flux aggregator feed accounts
+CACHE_PRICES = construct.Struct(
+    "variant" / construct.Const(7, construct.BytesInteger(4, swapped=True)),
+)
+
+
+# /// DEPRECATED - caching of root banks now happens in update index
+# /// Cache root banks
+# ///
+# /// Accounts expected: 2 + Root Banks
+# /// 0. `[]` mango_group_ai
+# /// 1. `[writable]` mango_cache_ai
+CACHE_ROOT_BANKS = construct.Struct(
+    "variant" / construct.Const(8, construct.BytesInteger(4, swapped=True)),
+)
+
+
 # /// Place an order on the Serum Dex using Mango account
 # /// Accounts expected by this instruction (22+openorders):
 # { isSigner: false, isWritable: false, pubkey: mangoGroupPk },
@@ -1410,7 +1432,7 @@ WITHDRAW = construct.Struct(
 #     pubkey,
 # })),
 PLACE_SPOT_ORDER = construct.Struct(
-    "variant" / construct.Const(9, construct.BytesInteger(4, swapped=True)),  # 4
+    "variant" / construct.Const(9, construct.BytesInteger(4, swapped=True)),
     "side" / DecimalAdapter(4),  # 8
     "limit_price" / DecimalAdapter(),  # 16
     "max_base_quantity" / DecimalAdapter(),  # 24
@@ -1487,6 +1509,31 @@ CONSUME_EVENTS = construct.Struct(
 )
 
 
+# /// Cache perp markets
+# ///
+# /// Accounts expected: 2 + Perp Markets
+# /// 0. `[]` mango_group_ai
+# /// 1. `[writable]` mango_cache_ai
+CACHE_PERP_MARKETS = construct.Struct(
+    "variant" / construct.Const(16, construct.BytesInteger(4, swapped=True)),
+)
+
+
+# /// Update funding related variables
+#
+# Seems to take:
+#   const keys = [
+#     { isSigner: false, isWritable: false, pubkey: mangoGroupPk },
+#     { isSigner: false, isWritable: true, pubkey: mangoCachePk },
+#     { isSigner: false, isWritable: true, pubkey: perpMarketPk },
+#     { isSigner: false, isWritable: false, pubkey: bidsPk },
+#     { isSigner: false, isWritable: false, pubkey: asksPk },
+#   ];
+UPDATE_FUNDING = construct.Struct(
+    "variant" / construct.Const(17, construct.BytesInteger(4, swapped=True)),
+)
+
+
 # /// Settle all funds from serum dex open orders
 # ///
 # /// Accounts expected by this instruction (18):
@@ -1527,6 +1574,16 @@ CANCEL_SPOT_ORDER = construct.Struct(
     "order_id" / DecimalAdapter(16),
 )
 
+# /// Update a root bank's indexes by providing all it's node banks
+# ///
+# /// Accounts expected: 2 + Node Banks
+# /// 0. `[]` mango_group_ai - MangoGroup
+# /// 1. `[]` root_bank_ai - RootBank
+# /// 2+... `[]` node_bank_ais - NodeBanks
+UPDATE_ROOT_BANK = construct.Struct(
+    "variant" / construct.Const(21, construct.BytesInteger(4, swapped=True)),
+)
+
 
 # /// Redeem the mngo_accrued in a PerpAccount for MNGO in MangoAccount deposits
 # ///
@@ -1758,8 +1815,8 @@ InstructionParsersByVariant = {
     4: UNSPECIFIED,  # ADD_SPOT_MARKET,
     5: UNSPECIFIED,  # ADD_TO_BASKET,
     6: UNSPECIFIED,  # BORROW,
-    7: UNSPECIFIED,  # CACHE_PRICES,
-    8: UNSPECIFIED,  # CACHE_ROOT_BANKS,
+    7: CACHE_PRICES,  # CACHE_PRICES,
+    8: CACHE_ROOT_BANKS,  # CACHE_ROOT_BANKS,
     9: PLACE_SPOT_ORDER,  # PLACE_SPOT_ORDER,
     10: UNSPECIFIED,  # ADD_ORACLE,
     11: UNSPECIFIED,  # ADD_PERP_MARKET,
@@ -1767,12 +1824,12 @@ InstructionParsersByVariant = {
     13: CANCEL_PERP_ORDER_BY_CLIENT_ID,  # CANCEL_PERP_ORDER_BY_CLIENT_ID,
     14: CANCEL_PERP_ORDER,  # CANCEL_PERP_ORDER,
     15: CONSUME_EVENTS,  # CONSUME_EVENTS,
-    16: UNSPECIFIED,  # CACHE_PERP_MARKETS,
-    17: UNSPECIFIED,  # UPDATE_FUNDING,
+    16: CACHE_PERP_MARKETS,  # CACHE_PERP_MARKETS,
+    17: UPDATE_FUNDING,  # UPDATE_FUNDING,
     18: UNSPECIFIED,  # SET_ORACLE,
     19: SETTLE_FUNDS,  # SETTLE_FUNDS,
     20: CANCEL_SPOT_ORDER,  # CANCEL_SPOT_ORDER,
-    21: UNSPECIFIED,  # UPDATE_ROOT_BANK,
+    21: UPDATE_ROOT_BANK,  # UPDATE_ROOT_BANK,
     22: UNSPECIFIED,  # SETTLE_PNL,
     23: UNSPECIFIED,  # SETTLE_BORROW,
     24: UNSPECIFIED,  # FORCE_CANCEL_SPOT_ORDERS,
